@@ -16,7 +16,7 @@
 """Config parsing functionality based on pydantic's BaseSettings"""
 
 import os
-import pathlib
+from pathlib import Path
 from typing import Any, Callable, Dict, Final, Optional
 
 import yaml
@@ -26,32 +26,57 @@ from pydantic import BaseSettings
 DEFAULT_CONFIG_PREFIX: Final = "ghga_services"
 
 
-def get_default_config_yaml(prefix: str) -> Optional[str]:
+class ConfigYamlDoesNotExist(RuntimeError):
+    """Thrown when the context manager is used out of context."""
+
+    def __init__(self, path: Path, specified_via: Optional[str] = None):
+        message = (
+            "The config yaml " + ""
+            if specified_via is None
+            else f"specified via {specified_via} " + f"does not exist: {path}"
+        )
+        super().__init__(message)
+
+
+def get_default_config_yaml(prefix: str) -> Optional[Path]:
     """Get the path to the default config function.
 
     Args:
         prefix (str):
             Name prefix used to derive the default paths.
     """
+    # check if path to config is set as env variable:
+    path_env_var = f"{prefix.upper()}_CONFIG_YAML"
+    try:
+        path_via_env_var = Path(os.environ[path_env_var])
+        if path_via_env_var.is_file():
+            return path_via_env_var
+        raise ConfigYamlDoesNotExist(
+            path=path_via_env_var,
+            specified_via=f"the environment variable {path_env_var}",
+        )
+    except KeyError:
+        pass
+
     # construct file name from prefix:
     file_name = f".{prefix}.yaml"
 
     # look in the current directory:
-    default_pwd_path = os.path.join(os.getcwd(), file_name)
-    if os.path.isfile(default_pwd_path):
-        return default_pwd_path
+    path_in_cwd = Path(os.getcwd()) / file_name
+    if os.path.isfile(path_in_cwd):
+        return path_in_cwd
 
     # look in the home directory:
-    default_home_path = os.path.join(pathlib.Path.home(), file_name)
-    if os.path.isfile(default_home_path):
-        return default_home_path
+    path_in_home = Path.home() / file_name
+    if os.path.isfile(path_in_home):
+        return path_in_home
 
     # if nothing was found return None:
     return None
 
 
 def yaml_settings_factory(
-    config_yaml: Optional[str] = None,
+    config_yaml: Optional[Path] = None,
 ) -> Callable[[BaseSettings], Dict[str, Any]]:
     """
     A factory of source methods for pydantic's BaseSettings Config that load
@@ -85,7 +110,9 @@ def config_from_yaml(
         - parameters passed using **kwargs
         - environment variables
         - file secrets
-        - yaml config file
+        - yaml config - path specified via env variable `{prefix}_CONFIG_YAML`
+                        (all uppercase)
+        - yaml config - file named `.{prefix}.yaml` and placed in the CWD or home dir
         - defaults
 
     Args:
@@ -117,7 +144,7 @@ def config_from_yaml(
             )
 
         def constructor_wrapper(
-            config_yaml: Optional[str] = None,
+            config_yaml: Optional[Path] = None,
             **kwargs,
         ):
             """A wrapper for constructing a pydantic BaseSetting with modified sources
@@ -130,6 +157,9 @@ def config_from_yaml(
             # get default path if config_yaml not specified:
             if config_yaml is None:
                 config_yaml = get_default_config_yaml(prefix)
+            else:
+                if not config_yaml.is_file():
+                    raise ConfigYamlDoesNotExist(path=config_yaml)
 
             class ModSettings(settings):  # type: ignore
                 """Modifies the orginal Settings class provided by the user"""
