@@ -17,6 +17,8 @@
 Test S3 storage DAO
 """
 
+from pathlib import Path
+
 import pytest
 from testcontainers.localstack import LocalStackContainer
 
@@ -27,14 +29,15 @@ from ghga_service_chassis_lib.object_storage_dao import (
     ObjectNotFoundError,
     ObjectStorageDao,
 )
-from ghga_service_chassis_lib.s3 import ObjectStorageS3
-
-from .fixtures.s3 import (
-    create_existing_object_and_bucket,
+from ghga_service_chassis_lib.object_storage_dao_testing import (
     download_and_check_test_file,
-    get_test_config,
-    upload_test_file,
+    populate_storage,
+    upload_file,
 )
+from ghga_service_chassis_lib.s3 import ObjectStorageS3
+from ghga_service_chassis_lib.s3_testing import config_from_localstack_container
+
+from .fixtures.storage import OBJECT_FIXTURE
 
 
 # This workflow is defined as a seperate function so that it can also be used
@@ -44,6 +47,8 @@ def typical_workflow(
     bucket1_id: str = "mytestbucket1",
     bucket2_id: str = "mytestbucket2",
     object_id: str = "mytestfile",
+    test_file_path: Path = OBJECT_FIXTURE.file_path,
+    test_file_md5: str = OBJECT_FIXTURE.md5,
 ):
     """
     Run a typical workflow of basic object operations using a S3 service.
@@ -60,7 +65,9 @@ def typical_workflow(
     upload_url = storage_client.get_object_upload_url(
         bucket_id=bucket1_id, object_id=object_id
     )
-    upload_test_file(upload_url)
+    upload_file(
+        presigned_url=upload_url, file_path=test_file_path, file_md5=test_file_md5
+    )
 
     print(" - confirm object upload")
     assert storage_client.does_object_exist(bucket_id=bucket1_id, object_id=object_id)
@@ -69,7 +76,9 @@ def typical_workflow(
     download_url1 = storage_client.get_object_download_url(
         bucket_id=bucket1_id, object_id=object_id
     )
-    download_and_check_test_file(download_url1)
+    download_and_check_test_file(
+        presigned_url=download_url1, expected_md5=test_file_md5
+    )
 
     print(f" - create a second bucket {bucket2_id} and move the object there")
     storage_client.create_bucket(bucket2_id)
@@ -97,7 +106,9 @@ def typical_workflow(
     download_url2 = storage_client.get_object_download_url(
         bucket_id=bucket2_id, object_id=object_id
     )
-    download_and_check_test_file(download_url2)
+    download_and_check_test_file(
+        presigned_url=download_url2, expected_md5=test_file_md5
+    )
 
     print("Done.")
 
@@ -107,7 +118,9 @@ def test_typical_workflow():
     Tests all methods of the ObjectStorageS3 DAO implementation in one long workflow.
     """
     with LocalStackContainer().with_services("s3") as localstack:
-        with ObjectStorageS3(config=get_test_config(localstack.get_url())) as storage:
+        config = config_from_localstack_container(localstack)
+
+        with ObjectStorageS3(config=config) as storage:
             typical_workflow(storage)
 
 
@@ -117,9 +130,14 @@ def test_object_and_bucket_collisions():
     """
 
     with LocalStackContainer().with_services("s3") as localstack:
-        with ObjectStorageS3(config=get_test_config(localstack.get_url())) as storage:
-            existing_bucket_id, existing_object_id = create_existing_object_and_bucket(
-                storage
+        existing_bucket_id = OBJECT_FIXTURE.bucket_id
+        existing_object_id = OBJECT_FIXTURE.object_id
+        config = config_from_localstack_container(localstack)
+
+        with ObjectStorageS3(config=config) as storage:
+            populate_storage(
+                storage=storage,
+                fixtures=[OBJECT_FIXTURE],
             )
 
             with pytest.raises(BucketAlreadyExists):
@@ -143,13 +161,17 @@ def test_handling_non_existing_file_and_bucket():
     """
     Tests whether the re-creaction of an existing bucket fails with the expected error.
     """
-    non_exisiting_bucket_id = "mynonexistingbucket"
-    non_existing_object_id = "mynonexistingobject"
-
     with LocalStackContainer().with_services("s3") as localstack:
-        with ObjectStorageS3(config=get_test_config(localstack.get_url())) as storage:
-            existing_bucket_id, existing_object_id = create_existing_object_and_bucket(
-                storage
+        non_exisiting_bucket_id = "mynonexistingbucket"
+        non_existing_object_id = "mynonexistingobject"
+        existing_bucket_id = OBJECT_FIXTURE.bucket_id
+        existing_object_id = OBJECT_FIXTURE.object_id
+        config = config_from_localstack_container(localstack)
+
+        with ObjectStorageS3(config=config) as storage:
+            populate_storage(
+                storage=storage,
+                fixtures=[OBJECT_FIXTURE],
             )
 
             with pytest.raises(BucketNotFoundError):
